#
# spec file for package python-python-multipart
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-multipart
Version:        0.0.17
Release:        1.2
License:        Apache-2.0
Summary:        Python streaming multipart parser
URL:            http://github.com/andrew-d/python-multipart
Source:         https://files.pythonhosted.org/packages/source/p/python-multipart/python_multipart-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
BuildArch:      noarch

%python_subpackages

%description
A streaming multipart parser for Python.

%prep
%autosetup -p1 -n python_multipart-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/multipart
%{python_sitelib}/python_multipart
%{python_sitelib}/python_multipart-%{version}.dist-info

%changelog
* Wed Nov  6 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.0.17
  * Handle PermissionError in fallback code for old import name #182
- from version 0.0.16
  * Add dunder attributes to `multipart` package #177
- from version 0.0.15
  * Replace `FutureWarning` to `PendingDeprecationWarning` #174
  * Add missing files to SDist #171
- from version 0.0.14
  * Fix import scheme for `multipart` module #168
- from version 0.0.13
  * Rename import to `python_multipart` #166
- from version 0.0.12
  * Improve error message when boundary character does not match #124
  * Add mypy strict typing #140
  * Enforce 100%% coverage #159
- from version 0.0.11
  * Improve performance, especially in data with many CR-LF #137
  * Handle invalid CRLF in header name #141
- from version 0.0.10
  * Support `on_header_begin` #103
  * Improve type hints on `FormParser` #104
  * Fix `OnFileCallback` type #106
  * Improve type hints #110
  * Improve type hints on `File` #111
  * Add type hint to helper functions #112
  * Minor fix for Field.__repr__ #114
  * Fix use of chunk_size parameter #136
  * Allow digits and valid token chars in headers #134
  * Fix headers being carried between parts #135
- Add python_multipart Python directory to %%files section
- Rename README.rst to README.md in %%files section
* Fri Mar  1 2024 Dirk Müller <dmueller@suse.com>
- update to 0.0.9:
  * Add support for Python 3.12 #85.
  * Drop support for Python 3.7 #95.
  * Add `MultipartState(IntEnum)` #96.
  * Add `QuerystringState` #97.
  * Add `TypedDict` callbacks #98.
  * Add config `TypedDict`s #99.
  * Cleanup unused regex patterns
  * Check if `Message.get_params` return 3-`tuple` instead of
    `str` on `parse_options_header`
* Tue Feb  6 2024 pgajdos@suse.com
- version update to 0.0.7
  0.0.7 (2024-02-03)
  * Refactor header option parser to use the standard library instead of a custom RegEx #75.
  [bsc#1219610] CVE-2024-24762
  0.0.6 (2023-02-27)
  * Migrate package installation to pyproject.toml (PEP 621) #54.
  * Use yaml.safe_load instead of yaml.load #46.
  * Add support for Python 3.11, drop EOL 3.6 #51.
  * Add support for Python 3.8-3.10, drop EOL 2.7-3.5 #42.
  * QuerystringParser: don't raise an AttributeError in __repr__ #30.
- deleted patches
  - python-python-multipart-no-mock.patch (upstreamed)
  - python-python-multipart-no-six.patch (upstreamed)
  - support-pyyaml-6.patch (upstreamed)
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jan  4 2023 Ben Greiner <code@bnavigator.de>
- Really don't require six
- Move to PEP517 build
* Mon Dec 12 2022 pgajdos@suse.com
- do not require six
- added patches
  fix https://github.com/andrew-d/python-multipart/commit/c54ad6006bacc77623864ec8e5c96bfd32230e01
  + python-python-multipart-no-six.patch
* Fri Apr  8 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/andrew-d/python-multipart/commit/8cff1aac7479fbb69087e355f66315b21640bab0
  + python-python-multipart-no-mock.patch
* Fri Feb  4 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-pyyaml-6.patch:
  * Support PyYAML 6.0+
* Sat Jul 25 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.0.5
